summaryrefslogtreecommitdiff
path: root/svx/inc/svx/svdview.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'svx/inc/svx/svdview.hxx')
-rw-r--r--svx/inc/svx/svdview.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/svx/inc/svx/svdview.hxx b/svx/inc/svx/svdview.hxx
index 4e390a4554e7..74b4bf9587a5 100644
--- a/svx/inc/svx/svdview.hxx
+++ b/svx/inc/svx/svdview.hxx
@@ -286,14 +286,14 @@ public:
void MoveHandleByVector(const SdrHdl& rHdl, const basegfx::B2DVector& rDistance, Window* pMakeVisibleWindow, SdrDragMethod* pOwnDragMethod);
/// find a SdrObject at position in rSource; evtl exclude a given SdrEdgeObj (pAvoidConnectioWith)
/// from that search. If no SdrObject connection is found, null is returned
SdrObject* FindConnector(
const basegfx::B2DPoint& rPosition,
sal_uInt32& o_rnID,
bool& o_rbBest,
bool& o_rbAuto,
- const SdrEdgeObj* pAvoidConnectioWith);
+ const SdrEdgeObj* pAvoidConnectionWith);
};
////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -286,14 +286,14 @@ public:
void MoveHandleByVector(const SdrHdl& rHdl, const basegfx::B2DVector& rDistance, Window* pMakeVisibleWindow, SdrDragMethod* pOwnDragMethod);
- /// find a SdrObject at position in rSource; evtl exclude a given SdrEdgeObj (pAvoidConnectioWith)
+ /// find a SdrObject at position in rSource; evtl exclude a given SdrEdgeObj (pAvoidConnectionWith)
/// from that search. If no SdrObject connection is found, null is returned
SdrObject* FindConnector(